Method: Bumbleworks::ProcessDefinition#initialize

Defined in:
lib/bumbleworks/process_definition.rb

#initialize(opts = {}) ⇒ ProcessDefinition

Initialize a new ProcessDefinition, supplying a name (required), and definition or a tree (one of which is required). The definition should be a string with a Bumbleworks.define_process block, and the tree should be an actual Ruote tree.



18
19
20
21
22
# File 'lib/bumbleworks/process_definition.rb', line 18

def initialize(opts = {})
  @name = opts[:name]
  @definition = opts[:definition]
  @tree = opts[:tree]
end