Method: Bumbleworks::Configuration#root
- Defined in:
- lib/bumbleworks/configuration.rb
#root ⇒ Object
Root folder where Bumbleworks looks for ruote assets (participants, process_definitions, etc.) The root path must be absolute. It can be defined through a configuration block:
Bumbleworks.configure { |c| c.root = '/somewhere' }
Or directly:
Bumbleworks.root = '/somewhere/else/'
If the root is not defined, Bumbleworks will use the root of known frameworks (Rails, Sinatra and Rory), appending “lib/bumbleworks”. Otherwise, it will raise an error if not defined.
253 254 255 256 257 258 |
# File 'lib/bumbleworks/configuration.rb', line 253 def root @root ||= begin raise UndefinedSetting.new("Bumbleworks.root must be set") unless framework_root File.join(framework_root, "lib", "bumbleworks") end end |